/*
 * $Id: rb_ecore.c 60 2004-08-10 14:12:36Z tilman $
 *
 * Copyright (C) 2004 Tilman Sauerbeck (tilman at code-monkey de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <ruby.h>

#include <Ecore.h>

#define __RB_ECORE_C
#include "rb_ecore.h"
#include "rb_timer.h"
#include "rb_idler.h"

VALUE mEcore;

/*
 * call-seq:
 *  Ecore.main_loop_begin
 *
 * Starts the Ecore main loop.
 */
static VALUE m_main_loop_begin (VALUE self)
{
	ecore_main_loop_begin ();

	return Qnil;
}

/*
 * call-seq:
 *  Ecore.main_loop_iterate
 *
 * Run one iteration of the Ecore main loop.
 */
static VALUE m_main_loop_iterate (VALUE self)
{
	ecore_main_loop_iterate ();

	return Qnil;
}

/*
 * call-seq:
 *  Ecore.main_loop_quit
 *
 * Stops the Ecore main loop.
 */
static VALUE m_main_loop_quit (VALUE self)
{
	ecore_main_loop_quit ();

	return Qnil;
}

void Init_ecore (void)
{
	mEcore = rb_define_module ("Ecore");

	rb_define_module_function (mEcore, "main_loop_begin",
	                           m_main_loop_begin, 0);
	rb_define_module_function (mEcore, "main_loop_iterate",
	                           m_main_loop_iterate, 0);
	rb_define_module_function (mEcore, "main_loop_quit",
	                           m_main_loop_quit, 0);

	Init_Timer ();
	Init_Idler ();
}

